package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class PolicyQualifierInfo extends ASN1Encodable {
   private DERObjectIdentifier policyQualifierId;
   private DEREncodable qualifier;

   public PolicyQualifierInfo(DERObjectIdentifier policyQualifierId, DEREncodable qualifier) {
      this.policyQualifierId = policyQualifierId;
      this.qualifier = qualifier;
   }

   public PolicyQualifierInfo(String cps) {
      this.policyQualifierId = PolicyQualifierId.id_qt_cps;
      this.qualifier = new DERIA5String(cps);
   }

   public PolicyQualifierInfo(ASN1Sequence as) {
      if (as.size() == 2) {
         this.policyQualifierId = DERObjectIdentifier.getInstance(as.getObjectAt(0));
         this.qualifier = as.getObjectAt(1);
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + as.size());
      }
   }

   public static PolicyQualifierInfo getInstance(Object as) {
      if (as instanceof PolicyQualifierInfo) {
         return (PolicyQualifierInfo)as;
      } else if (as instanceof ASN1Sequence) {
         return new PolicyQualifierInfo((ASN1Sequence)as);
      } else {
         throw new IllegalArgumentException("unknown object in getInstance.");
      }
   }

   public DERObjectIdentifier getPolicyQualifierId() {
      return this.policyQualifierId;
   }

   public DEREncodable getQualifier() {
      return this.qualifier;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.policyQualifierId);
      var10000.add(this.qualifier);
      return new DERSequence(var1);
   }
}
